@@ -10,10 +10,10 @@ class QStyleSyntaxHighlighter(QSyntaxHighlighter):
     def __init__(self, document: QTextDocument | None = None):
         super().__init__(document)
 
-        self.m_syntaxStyle: QSyntaxStyle.QSyntaxStyle | None = None
+        self._syntaxStyle: QSyntaxStyle.QSyntaxStyle | None = None
 
     def setSyntaxStyle(self, style: QSyntaxStyle.QSyntaxStyle | None):
-        self.m_syntaxStyle = style
+        self._syntaxStyle = style
 
     def syntaxStyle(self) -> QSyntaxStyle.QSyntaxStyle | None:
-        return self.m_syntaxStyle
+        return self._syntaxStyle
